"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "usePreview_unstable", {
    enumerable: true,
    get: function() {
        return usePreview_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _keyboardkeys = require("@fluentui/keyboard-keys");
const _reactcomponents = require("@fluentui/react-components");
const _reactutilities = require("@fluentui/react-utilities");
const _utils = require("../../utils");
const POPOVER_MOUSE_DELAY = 250;
const POPOVER_KEYBOARD_HIDE_DELAY = 0;
const getDelay = (type, popoverMouseHideDelay)=>{
    if (type === 'focus' || type === 'blur') {
        return POPOVER_KEYBOARD_HIDE_DELAY;
    }
    return popoverMouseHideDelay;
};
const usePreview_unstable = (props)=>{
    const { hideDelay = POPOVER_MOUSE_DELAY, onOpenChange, open, positioning, showDelay = POPOVER_MOUSE_DELAY, unstable_disableAutoFocus } = props;
    const children = _react.Children.toArray(props.children);
    const { targetDocument } = (0, _reactcomponents.useFluent)();
    const [setEnterTimeout, clearEnterTimeout] = (0, _reactutilities.useTimeout)();
    const [setLeaveTimeout, clearLeaveTimeout] = (0, _reactutilities.useTimeout)();
    const [disableAutoFocus, setDisableAutoFocus] = _react.useState(true);
    const { current: previewInternalState } = _react.useRef({
        openByClick: false,
        openByHoverOverTrigger: false,
        openByHoverOverPopover: false,
        openByKeyboard: false
    });
    const triggerMousedOver = _react.useRef(false);
    const isOpen = ()=>{
        return previewInternalState.openByClick || previewInternalState.openByHoverOverTrigger || previewInternalState.openByHoverOverPopover || previewInternalState.openByKeyboard;
    };
    const [isPopoverOpen, setIsPopoverOpen] = _react.useState(false);
    const preventDefaultClose = _react.useRef(false);
    let popoverTrigger = undefined;
    let popoverSurface = undefined;
    if (children.length === 2) {
        popoverTrigger = children[0];
        popoverSurface = children[1];
    } else if (children.length === 1) {
        popoverSurface = children[0];
    }
    const popoverSurfaceId = (0, _reactcomponents.useId)('preview-surface', popoverSurface === null || popoverSurface === void 0 ? void 0 : popoverSurface.props.id);
    const closeCallback = ()=>{
        previewInternalState.openByClick = false;
        previewInternalState.openByHoverOverTrigger = false;
        previewInternalState.openByHoverOverPopover = false;
        previewInternalState.openByKeyboard = false;
        setIsPopoverOpen(isOpen());
        clearEnterTimeout();
    };
    _react.useEffect(()=>{
        return ()=>{
            // Remove all instances of the current popover from the openedByHoverPreviewManager when the component is unmounted.
            (0, _utils.removeOpenedByHoverPreview)(popoverSurfaceId);
        };
    }, [
        popoverSurfaceId
    ]);
    if (popoverSurface && popoverTrigger) {
        const handleTriggerTargetEnter = (e)=>{
            previewInternalState.openByHoverOverTrigger = true;
            triggerMousedOver.current = true;
            // We want to disable auto focus only if the popover is being opened by hovering over the trigger
            if (!previewInternalState.openByClick && !previewInternalState.openByKeyboard && !isPopoverOpen) {
                setDisableAutoFocus(true);
                (0, _utils.closeAllOpenedByHoverPreviews)(popoverSurfaceId);
            }
            setEnterTimeout(()=>{
                if (!previewInternalState.openByClick && !previewInternalState.openByKeyboard && !isPopoverOpen && isOpen()) {
                    onOpenChange === null || onOpenChange === void 0 ? void 0 : onOpenChange(e, {
                        open: true
                    });
                    (0, _utils.addOpenedByHoverPreview)(popoverSurfaceId, closeCallback);
                }
                setIsPopoverOpen(isOpen());
            }, showDelay);
        };
        const handleTriggerTargetLeave = (e)=>{
            previewInternalState.openByHoverOverTrigger = false;
            triggerMousedOver.current = false;
            setLeaveTimeout(()=>{
                setIsPopoverOpen(isOpen());
                // We want to call onOpenChange only if the popover is actually closing when leaving the trigger
                if (!previewInternalState.openByClick && !previewInternalState.openByKeyboard && !previewInternalState.openByHoverOverPopover && isPopoverOpen) {
                    onOpenChange === null || onOpenChange === void 0 ? void 0 : onOpenChange(e, {
                        open: false
                    });
                    (0, _utils.removeOpenedByHoverPreview)(popoverSurfaceId);
                }
            }, getDelay(e.type, hideDelay));
        };
        const handleTriggerClick = (e)=>{
            // Setting preventDefaultClose so that onPopoverOpenChange does not apply its logic when click is on the trigger as we want to control that behavior.
            preventDefaultClose.current = true;
            // We set disableAutoFocus to false so that interactive elements within popover can be focused when it opens via click.
            setDisableAutoFocus(false);
            const tmpOpenByHoverOverTrigger = previewInternalState.openByHoverOverTrigger;
            // If openByKeyboard is true, then the popover was already opened via keyboard and we always want to close it.
            previewInternalState.openByClick = previewInternalState.openByKeyboard ? false : !previewInternalState.openByClick;
            previewInternalState.openByHoverOverTrigger = false;
            previewInternalState.openByHoverOverPopover = false;
            previewInternalState.openByKeyboard = false;
            // We set triggerMousedOver to false when clicking, since we just interacted with the trigger via click, and not hover.
            if (triggerMousedOver.current) {
                previewInternalState.openByClick = false;
                triggerMousedOver.current = false;
            } else {
                e.preventDefault();
            }
            if (!tmpOpenByHoverOverTrigger) {
                onOpenChange === null || onOpenChange === void 0 ? void 0 : onOpenChange(e, {
                    open: previewInternalState.openByClick
                });
            }
            if (!isOpen()) {
                (0, _utils.removeOpenedByHoverPreview)(popoverSurfaceId);
            }
            setIsPopoverOpen(isOpen());
        };
        const handleTriggerKeyDown = (e)=>{
            if (e.key === _keyboardkeys.Enter) {
                clearLeaveTimeout();
                // Setting default prevented so that Enter key does not trigger a click event or onPopoverOpenChange.
                e.preventDefault();
                // We set disableAutoFocus to false so that interactive elements within popover can be focused when it opens via keyboard.
                setDisableAutoFocus(false);
                const tmpOpenByHoverOverTrigger = previewInternalState.openByHoverOverTrigger;
                // If openByClick is true, then the popover was already opened via click and we always want to close it.
                previewInternalState.openByKeyboard = previewInternalState.openByClick ? false : !previewInternalState.openByKeyboard;
                previewInternalState.openByClick = false;
                previewInternalState.openByHoverOverTrigger = false;
                previewInternalState.openByHoverOverPopover = false;
                if (!tmpOpenByHoverOverTrigger) {
                    onOpenChange === null || onOpenChange === void 0 ? void 0 : onOpenChange(e, {
                        open: previewInternalState.openByKeyboard
                    });
                }
                if (!isOpen()) {
                    (0, _utils.removeOpenedByHoverPreview)(popoverSurfaceId);
                }
                setIsPopoverOpen(isOpen());
            }
        };
        const handlePopoverTargetEnter = (e)=>{
            previewInternalState.openByHoverOverPopover = true;
            setIsPopoverOpen(isOpen());
        };
        const handlePopoverTargetLeave = (e)=>{
            previewInternalState.openByHoverOverPopover = false;
            setLeaveTimeout(()=>{
                setIsPopoverOpen(isOpen());
                // We want to call onOpenChange only if the popover is actually closing when leaving the popover
                if (!previewInternalState.openByClick && !previewInternalState.openByKeyboard && !previewInternalState.openByHoverOverTrigger) {
                    onOpenChange === null || onOpenChange === void 0 ? void 0 : onOpenChange(e, {
                        open: false
                    });
                    (0, _utils.removeOpenedByHoverPreview)(popoverSurfaceId);
                }
            }, getDelay(e.type, hideDelay));
        };
        popoverTrigger = /*#__PURE__*/ _react.cloneElement(popoverTrigger, {
            ...popoverTrigger.props,
            children: /*#__PURE__*/ _react.cloneElement(popoverTrigger.props.children, {
                ...popoverTrigger.props.children.props,
                onBlur: (0, _reactcomponents.mergeCallbacks)(popoverTrigger.props.children.props.onBlur, handleTriggerTargetLeave),
                onClick: (0, _reactcomponents.mergeCallbacks)(popoverTrigger.props.children.props.onClick, handleTriggerClick),
                onKeyDown: (0, _reactcomponents.mergeCallbacks)(popoverTrigger.props.children.props.onKeyDown, handleTriggerKeyDown),
                onMouseEnter: (0, _reactcomponents.mergeCallbacks)(popoverTrigger.props.children.props.onMouseEnter, handleTriggerTargetEnter),
                onMouseLeave: (0, _reactcomponents.mergeCallbacks)(popoverTrigger.props.children.props.onMouseLeave, handleTriggerTargetLeave)
            })
        });
        var _popoverSurface_props_arialabelledby;
        popoverSurface = /*#__PURE__*/ _react.cloneElement(popoverSurface, {
            ...popoverSurface.props,
            'aria-labelledby': (_popoverSurface_props_arialabelledby = popoverSurface.props['aria-labelledby']) !== null && _popoverSurface_props_arialabelledby !== void 0 ? _popoverSurface_props_arialabelledby : popoverSurface.props['aria-label'] ? undefined : popoverSurfaceId,
            id: popoverSurfaceId,
            onMouseEnter: (0, _reactcomponents.mergeCallbacks)(popoverSurface.props.onMouseEnter, handlePopoverTargetEnter),
            onMouseLeave: (0, _reactcomponents.mergeCallbacks)(popoverSurface.props.onMouseLeave, handlePopoverTargetLeave),
            onFocus: (0, _reactcomponents.mergeCallbacks)(popoverSurface.props.onFocus, handlePopoverTargetEnter)
        });
    }
    // Hitting Escape key should close the popover if it was opened by hover.
    // This is necessary to attach to the document because focus is likely not within the trigger or popover.
    (0, _reactcomponents.useIsomorphicLayoutEffect)(()=>{
        if (isPopoverOpen) {
            const onDocumentKeyDown = (e)=>{
                const openedByHover = !previewInternalState.openByClick && !previewInternalState.openByKeyboard;
                if (openedByHover && e.key === _keyboardkeys.Escape) {
                    clearLeaveTimeout();
                    // We set state back to its default if the Escape key has been pressed
                    setDisableAutoFocus(true);
                    closeCallback();
                    (0, _utils.removeOpenedByHoverPreview)(popoverSurfaceId);
                    onOpenChange === null || onOpenChange === void 0 ? void 0 : onOpenChange(e, {
                        open: false
                    });
                    e.stopPropagation();
                }
            };
            targetDocument === null || targetDocument === void 0 ? void 0 : targetDocument.addEventListener('keydown', onDocumentKeyDown, {
                capture: true
            });
            return ()=>{
                targetDocument === null || targetDocument === void 0 ? void 0 : targetDocument.removeEventListener('keydown', onDocumentKeyDown, {
                    capture: true
                });
            };
        }
    }, [
        targetDocument,
        isPopoverOpen
    ]);
    const onPopoverOpenChange = (e, data)=>{
        if (!preventDefaultClose.current) {
            // We set all open state to false if preventDefaultClose was not set to true and the popover is closing.
            if (!data.open) {
                clearLeaveTimeout();
                closeCallback();
                (0, _utils.removeOpenedByHoverPreview)(popoverSurfaceId);
            }
            onOpenChange === null || onOpenChange === void 0 ? void 0 : onOpenChange(e, data);
        }
        preventDefaultClose.current = false;
    };
    let resolvedChildren = children;
    if (popoverSurface) {
        if (popoverTrigger) {
            resolvedChildren = [
                popoverTrigger,
                popoverSurface
            ];
        } else {
            resolvedChildren = popoverSurface;
        }
    }
    const popoverState = (0, _reactcomponents.usePopover_unstable)({
        ...props,
        children: resolvedChildren,
        onOpenChange: onPopoverOpenChange,
        open: open !== null && open !== void 0 ? open : isPopoverOpen,
        positioning: typeof positioning === 'string' ? {
            autoSize: true,
            ...(0, _reactcomponents.resolvePositioningShorthand)(positioning)
        } : {
            autoSize: true,
            ...positioning
        },
        unstable_disableAutoFocus: unstable_disableAutoFocus !== null && unstable_disableAutoFocus !== void 0 ? unstable_disableAutoFocus : disableAutoFocus
    });
    return {
        ...popoverState,
        isPreviewLocked: previewInternalState.openByClick || previewInternalState.openByKeyboard
    };
}; //# sourceMappingURL=usePreview.js.map
