import * as React from 'react';
import { getIntrinsicElementProps, mergeClasses, slot, useId } from '@fluentui/react-components';
import { previewHeaderExtraClassNames } from './usePreviewHeaderStyles.styles';
/**
 * Create the state required to render PreviewHeader.
 *
 * The returned state can be modified with hooks such as usePreviewHeaderStyles_unstable,
 * before being passed to renderPreviewHeader_unstable.
 *
 * @param props - props from this instance of PreviewHeader
 * @param ref - reference to root HTMLElement of PreviewHeader
 */
export const usePreviewHeader_unstable = (props, ref) => {
  var _state_media;
  const {
    actions,
    children,
    citation,
    label,
    media
  } = props;
  const mediaId = useId('media');
  const state = {
    components: {
      root: 'div',
      actions: 'div',
      citation: 'span',
      label: 'span',
      media: 'div'
    },
    root: slot.always(getIntrinsicElementProps('div', {
      ref,
      ...props
    }), {
      elementType: 'div'
    }),
    actions: slot.optional(actions, {
      elementType: 'div'
    }),
    citation: slot.optional(citation, {
      elementType: 'span'
    }),
    label: slot.always(label, {
      defaultProps: {
        children
      },
      elementType: 'span'
    }),
    media: slot.optional(media, {
      defaultProps: {
        id: mediaId
      },
      elementType: 'div'
    })
  };
  if ((_state_media = state.media) === null || _state_media === void 0 ? void 0 : _state_media.id) {
    var _state_label_ariadescribedby;
    var _state_label_ariadescribedby_concat;
    state.label['aria-describedby'] = (_state_label_ariadescribedby_concat = (_state_label_ariadescribedby = state.label['aria-describedby']) === null || _state_label_ariadescribedby === void 0 ? void 0 : _state_label_ariadescribedby.concat(state.media.id)) !== null && _state_label_ariadescribedby_concat !== void 0 ? _state_label_ariadescribedby_concat : state.media.id;
  }
  if (state.media && React.isValidElement(state.media.children)) {
    state.media.children = React.cloneElement(state.media.children, {
      className: mergeClasses(state.media.children.props.className, previewHeaderExtraClassNames.mediaChild)
    });
  }
  return state;
};
//# sourceMappingURL=usePreviewHeader.js.map